Changelog
=========


Version 0.17.2
--------------

Released on 2025-01-20.

* Fix Oriya dictionary name.
* Update documentation.


Version 0.17.1
--------------

Released on 2025-01-20.

* Update Mongolian dictionary.
* Add Assamese, Kannada, Sanskrit, Punjabi, Oriya, Marathi dictionaries.


Version 0.17.0
--------------

Released on 2024-10-28.

* Support Python 3.13, drop Python 3.8 support.
* Update Hungarian dictionary.


Version 0.16.0
--------------

Released on 2024-07-30.

* Close file when reading encoding
* Update dictionary repository


Version 0.15.0
--------------

Released on 2024-04-23.

* Support Python 3.12, drop Python 3.7 support.
* Add READMEs for dictionaries.
* Add Basque hyphenation dictionary.
* Update Catalan and Hungarian dictionaries.
* Use Ruff instead of Flake8 and isort.


Version 0.14.0
--------------

Released on 2023-03-17.

* Store Path objects instead of strings in LANGUAGES.
* Use importlib.resources instead of deprecated pkg_resources.


Version 0.13.2
--------------

Released on 2022-11-29.

* Add Thai dictionary.


Version 0.13.1
--------------

Released on 2022-11-15.

* Update Italian dictionary.


Version 0.13.0
--------------

Released on 2022-09-01.

* Make language parameter case-insensitive.
* Add Catalan dictionary.
* Update French dictionary.
* Update script upgrading dictionaries.


Version 0.12.0
--------------

Released on 2021-12-27.

* Support Python 3.10, drop Python 3.6 support.
* Add documentation.
* Update Belarusian dictionary.


Version 0.11.0
--------------

Released on 2021-06-26.

* Update dictionaries (add Albanian, Belarusian, Esperanto, Mongolian; update
  Italian, Portuguese of Brazil, Russian).
* Use Flit for packaging. You can now build packages using ``pip install
  flit``, ``flit build``.


Version 0.10.0
--------------

Released on 2020-10-29.


Version 0.9.5
-------------

Released on 2018-08-24.


Version 0.9.4
-------------

Released on 2016-01-24.


Version 0.9.3
-------------

Released on 2016-01-08.


Version 0.9.2
-------------

Released on 2015-09-28.


Version 0.9.1
-------------

Released on 2013-12-27.


Version 0.9
-----------

Released on 2013-12-27.


Version 0.8
-----------

Released on 2013-08-09.


Version 0.7
-----------

Released on 2013-02-26.


Version 0.6
-----------

Released on 2013-01-07.
